@@ -11,24 +11,36 @@ from reamber.quaver.lists.notes.QuaHoldList import QuaHoldList
 
 class BMSToQua(ConvertBase):
     @classmethod
-    def convert(cls, bms: BMSMap, assert_keys=True) -> QuaMap:
+    def convert(cls, bms: BMSMap, raise_bad_mode: bool = True) -> QuaMap:
         """ Converts a BMS to a Qua Map
 
-        :param bms:
-        :param assert_keys: Adds an assertion to verify that Quaver can support this key mode
-        :return:
+        Args
+            bms: BMS Map
+            raise_bad_mode: Raises if Quaver can't support this key mode
         """
 
         qua = QuaMap()
-        qua.hits = cls.cast(bms.hits, QuaHitList, dict(offset='offset', column='column'))
-        qua.holds = cls.cast(bms.holds, QuaHoldList, dict(offset='offset', column='column', length='length'))
-        qua.bpms = cls.cast(bms.bpms, QuaBpmList, dict(offset='offset', bpm='bpm'))
+        qua.hits = cls.cast(
+            bms.hits, QuaHitList, dict(offset='offset', column='column')
+        )
+        qua.holds = cls.cast(
+            bms.holds, QuaHoldList,
+            dict(offset='offset', column='column', length='length')
+        )
+        qua.bpms = cls.cast(
+            bms.bpms, QuaBpmList,
+            dict(offset='offset', bpm='bpm')
+        )
 
         qua.title = unidecode(bms.title.decode('sjis'))
         qua.mode = QuaMapMode.get_mode(int(bms.stack().column.max() + 1))
         qua.difficulty_name = unidecode(bms.version.decode('sjis'))
         qua.artist = unidecode(bms.artist.decode('sjis'))
 
-        if assert_keys: assert qua.mode, f"Current Keys {int(bms.stack().column.max() + 1)} is not supported"
+        if raise_bad_mode and not qua.mode:
+            raise ValueError(
+                f"Keys {int(bms.stack().column.max() + 1)} isn't supported"
+                f"by Quaver."
+            )
 
         return qua
