@@ -11,21 +11,21 @@ from reamber.osu.lists.notes.OsuHoldList import OsuHoldList
 class O2JToOsu(ConvertBase):
     @classmethod
     def convert(cls, o2js: O2JMapSet) -> List[OsuMap]:
-        """ Converts a Mapset to multiple Osu maps
-
-        Note that a mapset contains maps, so a list would be expected.
-        O2JMap conversion is not possible due to lack of O2JMapset Metadata
-
-        :param o2js:
-        :return:
-        """
+        """ Converts a Mapset to multiple Osu maps """
 
         osus: List[OsuMap] = []
         for o2j in o2js:
             osu = OsuMap()
-            osu.hits = cls.cast(o2j.hits, OsuHitList, dict(offset='offset', column='column'))
-            osu.holds = cls.cast(o2j.holds, OsuHoldList, dict(offset='offset', column='column', length='length'))
-            osu.bpms = cls.cast(o2j.bpms, OsuBpmList, dict(offset='offset', bpm='bpm'))
+            osu.hits = cls.cast(
+                o2j.hits, OsuHitList, dict(offset='offset', column='column')
+            )
+            osu.holds = cls.cast(
+                o2j.holds, OsuHoldList,
+                dict(offset='offset', column='column', length='length')
+            )
+            osu.bpms = cls.cast(
+                o2j.bpms, OsuBpmList, dict(offset='offset', bpm='bpm')
+            )
 
             osu.title = o2js.title
             osu.artist = o2js.artist
@@ -33,4 +33,5 @@ class O2JToOsu(ConvertBase):
             osu.version = f"Level {o2js.level_name(o2j)}"
             osu.circle_size = 7
             osus.append(osu)
+
         return osus
