@@ -10,19 +10,30 @@ from reamber.quaver.lists.notes.QuaHoldList import QuaHoldList
 
 class OsuToQua(ConvertBase):
     @classmethod
-    def convert(cls, osu: OsuMap, assert_keys=True) -> QuaMap:
+    def convert(cls, osu: OsuMap, raise_bad_mode: bool = True) -> QuaMap:
         """ Converts Osu to a Qua Map
 
-        :param osu:
-        :param assert_keys: Adds an assertion to verify that Quaver can support this key mode
-        :return:
+        Args:
+            osu: Osu Map
+            raise_bad_mode: Raises if Quaver can't support this key mode
         """
 
         qua = QuaMap()
-        qua.hits = cls.cast(osu.hits, QuaHitList, dict(offset='offset', column='column'))
-        qua.holds = cls.cast(osu.holds, QuaHoldList, dict(offset='offset', column='column', length='length'))
-        qua.bpms = cls.cast(osu.bpms, QuaBpmList, dict(offset='offset', bpm='bpm'))
-        qua.sv = cls.cast(osu.svs, QuaSvList, dict(offset='offset', multiplier='multiplier'))
+        qua.hits = cls.cast(
+            osu.hits, QuaHitList, dict(offset='offset', column='column')
+        )
+        qua.holds = cls.cast(
+            osu.holds, QuaHoldList,
+            dict(offset='offset', column='column', length='length')
+        )
+        qua.bpms = cls.cast(
+            osu.bpms, QuaBpmList,
+            dict(offset='offset', bpm='bpm')
+        )
+        qua.sv = cls.cast(
+            osu.svs, QuaSvList,
+            dict(offset='offset', multiplier='multiplier')
+        )
 
         qua.audio_file = osu.audio_file_name
         qua.title = osu.title
@@ -34,6 +45,10 @@ class OsuToQua(ConvertBase):
         qua.background_file = osu.background_file_name
         qua.song_preview_time = osu.preview_time
 
-        if assert_keys: assert qua.mode, f"Current Keys {int(osu.stack().column.max() + 1)} is not supported"
+        if raise_bad_mode and not qua.mode:
+            raise ValueError(
+                f"Keys {int(osu.stack().column.max() + 1)} isn't supported"
+                f"by Quaver."
+            )
 
         return qua
