@@ -12,33 +12,38 @@ from reamber.sm.SMMapSet import SMMapSet
 
 class SMToQua(ConvertBase):
     @classmethod
-    def convert(cls, sms: SMMapSet, assert_keys=True) -> List[QuaMap]:
+    def convert(cls, sms: SMMapSet, raise_bad_mode: bool = True)\
+        -> List[QuaMap]:
         """ Converts a SMMapset to possibly multiple quaver maps
 
-        Note that a mapset contains maps, so a list would be expected.
-        SMMap conversion is not possible due to lack of SMMapset Metadata
-
-        :param sm:
-        :param assert_keys: Adds an assertion to verify that Quaver can support this key mode
-        :return:
+        Args:
+            sms: Stepmania Mapset
+            raise_bad_mode: Raises if Quaver can't support this key mode
         """
 
         quas: List[QuaMap] = []
         for sm in sms:
             qua = QuaMap()
-            qua.hits = cls.cast(sm.hits, QuaHitList, dict(offset='offset', column='column'))
-            qua.holds = cls.cast(sm.holds, QuaHoldList, dict(offset='offset', column='column', length='length'))
-            qua.bpms = cls.cast(sm.bpms, QuaBpmList, dict(offset='offset', bpm='bpm'))
+            qua.hits = cls.cast(sm.hits, QuaHitList,
+                                dict(offset='offset', column='column'))
+            qua.holds = cls.cast(sm.holds, QuaHoldList,
+                                 dict(offset='offset', column='column',
+                                      length='length'))
+            qua.bpms = cls.cast(sm.bpms, QuaBpmList,
+                                dict(offset='offset', bpm='bpm'))
 
             qua.background_file = sms.background
             qua.title = sms.title
             qua.artist = sms.artist
-            qua.mode = QuaMapMode.get_mode(int(SMMapChartTypes.get_keys(sm.chart_type)))
+            qua.mode = QuaMapMode.get_mode(
+                int(SMMapChartTypes.get_keys(sm.chart_type)))
             qua.audio_file = sms.music
             qua.creator = sms.credit
             qua.difficulty_name = f"{sm.difficulty} {sm.difficulty_val}"
             qua.song_preview_time = int(sms.sample_start)
-            if assert_keys: assert qua.mode, f"Current Keys {int(sm.stack().column.max() + 1)} is not supported"
-
+            if raise_bad_mode and not qua.mode:
+                raise ValueError(
+                    f"Keys {int(sm.stack().column.max() + 1)} isn't supported."
+                )
             quas.append(qua)
         return quas
