@@ -16,11 +16,12 @@ class PFDrawOffsets(PFDrawable):
                  interval: float = 10000):
         """ Draws Bpms on the field
 
-        :param decimal_places: The number of decimal places to display
-        :param color: The color of the text
-        :param x_offset: Padding from the right, useful if you have multiple text drawables overlapping
-        :param y_offset: Padding from the top, useful if you have multiple text drawables overlapping
-        :param interval: MS Time between labels
+        Args:
+            decimal_places: Decimal places to display
+            color: The color of the text
+            x_offset: Padding from the right
+            y_offset: Padding from the top
+            interval: MS Time between labels
         """
         self.x_offset = x_offset
         self.y_offset = y_offset
@@ -34,11 +35,13 @@ class PFDrawOffsets(PFDrawable):
             txt = f"{offset:.{self.decimal_places}f}"
             w, h = pf.canvas_draw.textsize(txt)
 
-            pf.canvas_draw.text(xy=pf.get_pos(offset,
-                                              column=pf.keys,
-                                              x_offset=self.x_offset,
-                                              y_offset=self.y_offset - h / 2),
-                                text=txt,
-                                fill=self.color)
+            pf.canvas_draw.text(
+                xy=pf.get_pos(offset,
+                              column=pf.keys,
+                              x_offset=self.x_offset,
+                              y_offset=self.y_offset - h / 2),
+                text=txt,
+                fill=self.color
+            )
 
         return pf
