@@ -5,6 +5,6 @@ if TYPE_CHECKING:
     from reamber.algorithms.playField import PlayField
 
 class PFDrawable(ABC):
-    """ All PlayField Drawing classes must inherit from this to enable the __add__ op """
+    """ All PlayField Drawing classes inherit from enables the __add__ op """
     @abstractmethod
     def draw(self, pf: 'PlayField') -> 'PlayField': ...
