@@ -1,10 +1,11 @@
 from reamber.algorithms.playField.parts.PFDrawBeatLines import PFDrawBeatLines
 from reamber.algorithms.playField.parts.PFDrawBpm import PFDrawBpm
-from reamber.algorithms.playField.parts.PFDrawColumnLines import PFDrawColumnLines
+from reamber.algorithms.playField.parts.PFDrawColumnLines import \
+    PFDrawColumnLines
 from reamber.algorithms.playField.parts.PFDrawLines import PFDrawLines, PFLine
 from reamber.algorithms.playField.parts.PFDrawNotes import PFDrawNotes
 from reamber.algorithms.playField.parts.PFDrawOffsets import PFDrawOffsets
 from reamber.algorithms.playField.parts.PFDrawSv import PFDrawSv
 
-__all__ = ['PFDrawSv', 'PFDrawNotes', 'PFDrawBpm', 'PFDrawColumnLines', 'PFDrawBeatLines', 'PFDrawLines', 'PFLine',
-           'PFDrawOffsets']
+__all__ = ['PFDrawSv', 'PFDrawNotes', 'PFDrawBpm', 'PFDrawColumnLines',
+           'PFDrawBeatLines', 'PFDrawLines', 'PFLine', 'PFDrawOffsets']
