@@ -1,10 +1,7 @@
 from __future__ import annotations
 
-from copy import deepcopy
 from functools import total_ordering
 
-import numpy as np
-
 from reamber.base.Property import item_props, Properties
 from reamber.base.Series import Series
 
@@ -17,18 +14,21 @@ class Timed(Series):
     _props = dict(offset=['float', 0.0])
 
     def __init__(self, offset: float, **kwargs):
-        super().__init__(offset=offset, **kwargs)
+        """ Initializer
 
-    def __eq__(self, other: Timed):
-        return np.all(self.data == other.data)
+        Examples:
+            >>> t = Timed(offset=1000)
+            >>> t.offset
+            1000
+
+        Args:
+            offset: Offset in ms
+        """
+        super().__init__(offset=offset, **kwargs)
 
     def __gt__(self, other: Timed):
         return self.offset > other.offset
 
-    def deepcopy(self):
-        """ Returns a deep copy of itself """
-        return deepcopy(self)
-
     @classmethod
     def props(cls):
         return Properties(cls._props)
