@@ -1,5 +1,5 @@
 from abc import ABC
-from typing import List, Type, TypeVar
+from typing import TypeVar
 
 from reamber.base.Property import list_props
 from reamber.base.lists.notes.NoteList import NoteList
@@ -7,7 +7,7 @@ from reamber.bms.BMSHit import BMSHit
 
 Item = TypeVar('Item')
 
+
 @list_props(BMSHit)
 class BMSNoteList(NoteList[Item], ABC):
     ...
-
