@@ -1,7 +1,7 @@
 class OsuSampleSet:
-    """ Osu SampleSet are a "enum" of available hitsounds.
+    """ Osu SampleSet are an "enum" of available hitsounds.
 
-    Not to be confused with OsuSample, where that's a class for samples under [Events]
+    Not to be confused with OsuSample, a class for samples under [Events]
     """
     AUTO: int = 0
     NORMAL: int = 1
@@ -10,7 +10,7 @@ class OsuSampleSet:
 
     @staticmethod
     def to_string(sample_set: int) -> str:
-        """ Converts a integer to a string representing SampleSet """
+        """ Converts an int to a string representing SampleSet """
         if sample_set == OsuSampleSet.AUTO:     return "None"
         elif sample_set == OsuSampleSet.NORMAL: return "Normal"
         elif sample_set == OsuSampleSet.SOFT:   return "Soft"
@@ -19,7 +19,7 @@ class OsuSampleSet:
 
     @staticmethod
     def from_string(sample_set: str) -> int:
-        """ Converts a string to an integer """
+        """ Converts a SampleSet string to an int """
         if sample_set == "None":     return OsuSampleSet.AUTO
         elif sample_set == "Normal": return OsuSampleSet.NORMAL
         elif sample_set == "Soft":   return OsuSampleSet.SOFT
