@@ -14,13 +14,9 @@ class OsuBpmList(BpmList[OsuBpm]):
 
     @staticmethod
     def read(strings: List[str]) -> OsuBpmList:
-        """ A shortcut to reading OsuHit in a loop to create a OsuHitList
-
-        :param strings: A List of strings to loop through OsuHit.read
-        """
-        return OsuBpmList(pd.DataFrame([OsuBpm.read_string(s, as_dict=True) for s in strings]) if strings else [])
+        return OsuBpmList(pd.DataFrame(
+            [OsuBpm.read_string(s, as_dict=True) for s in strings]
+        ) if strings else [])
 
     def write(self) -> List[str]:
         return [h.write_string() for h in self]
-
-
