@@ -10,10 +10,11 @@ from reamber.base.Bpm import Bpm
 class QuaBpm(Bpm):
 
     def to_yaml(self):
-        """ Used to facilitate exporting as Qua from YAML """
         return dict(StartTime=int(self.offset), Bpm=float(self.bpm))
 
     @staticmethod
     def from_yaml(d: Dict[str, Any]):
-        s = pd.Series(dict(offset=d.get('StartTime', 0), bpm=d.get('Bpm', 120)))
+        s = pd.Series(
+            dict(offset=d.get('StartTime', 0), bpm=d.get('Bpm', 120))
+        )
         return QuaBpm.from_series(s)
