@@ -8,7 +8,6 @@ from reamber.base.Timed import Timed
 
 @item_props()
 class QuaSv(Timed):
-
     _props = dict(multiplier=['float', 1.0])
 
     def __init__(self, offset: float, multiplier: float = 1.0, **kwargs):
@@ -16,7 +15,8 @@ class QuaSv(Timed):
 
     def to_yaml(self) -> Dict:
         """ Used to facilitate exporting as Qua from YAML """
-        return dict(StartTime=int(self.offset), Multiplier=float(self.multiplier))
+        return dict(StartTime=int(self.offset),
+                    Multiplier=float(self.multiplier))
 
     @staticmethod
     def from_yaml(d: Dict[str, Any]):
