@@ -8,7 +8,7 @@ from reamber.base.lists.notes.NoteList import NoteList
 from reamber.quaver.QuaHit import QuaHit
 from reamber.quaver.lists.QuaTimedList import QuaTimedList
 
-Item = TypeVar('Item')
+Item = TypeVar('Item', bound=QuaHit)
 
 @list_props(QuaHit)
 class QuaNoteList(NoteList[Item], QuaTimedList[Item], ABC):
